/*
* $Author: $tklose
* $Date: 2014-03-07 12:08:40 GMT$
* $Revision: $0.4
*/
/** \page lld_filesAndConfig Files and Configuration

\section folders Folder structure

Starting from <B>src/ifx/\$(VERIF_DUT)</B>:
  \li <B>_Reg</B> contains the header files
  \li <B>_Impl</B> contains derivative specific configuration which could also be adapted by the user
  \li <B>_PinMap</B> contains I/O configurations in pin tables
  \li <B>_Lib</B> contains derivative dependent library functions
  \li <B>\<module\></B> contains the actual peripheral driver

In addition derivative independent service software sources are located under:
  \li <B>src/ifx/SrvSw</B>


\section includePaths Include Paths

Following include paths should be specified in the compile script (resp. Makefile) to compile the drivers:

\code
  -I$(VERIF_LLD)/src/ifx/$(VERIF_DUT)
  -I$(VERIF_LLD)/src/ifx/$(VERIF_DUT)/_Reg
  -I$(VERIF_LLD)/src/ifx/SrvSw
\endcode

  \li <B>VERIF_LLD</B> stands for the directory to the iLLD version
  \li <B>VERIF_DUT</B> stands for the derivative which should be selected


\section ifxCfgH IfxCfg.h

Please create a configuration file with the name "IfxCfg.h" in your application to
configure the iLLD library components.

Currently it only requires to select the external oscillator frequency (XTAL)
and the desired system frequency.

In addition, this file allows you to specify how assertions should be print out.

Minimal IfxCfg.h file:
\code
#ifndef IFX_CFG_H
#define IFX_CFG_H

// XTAL/PLL frequency
#define IFX_CFG_SCU_XTAL_FREQUENCY    (20000000)
#define IFX_CFG_SCU_PLL_FREQUENCY    (200000000)

// Assertions
#define IFX_ASSERT(level, expr)

#endif /* IFX_CFG_H */
\endcode


Example for Assertion output via printf:
\code
#ifdef  __cplusplus
extern "C" {
#endif
// defined in $VERIF_SRC/lib/main.c
extern const char* verboseLevelStr[6];

#define IFX_ASSERT(level, expr) (((expr) || (level > IFX_VERBOSE_LEVEL_ERROR)) ? ((void)0) : (void)printf("[ASSERT:%s] '%s' in %s:%d (function '%s')\n", verboseLevelStr[level], #expr, __FILE__, __LINE__, __func__))

#endif
\endcode


And in your main.c file (or somewhere else):

\code
//! this global array is used by IFX_ASSERT of iLLDs
const char* verboseLevelStr[6] = {
    "OFF",
    "FAILURE",
    "ERROR",
    "WARNING",
    "INFO",
    "DEBUG"
};
\endcode


\section minimalSetup Minimal Set of Driver sources

If you prefer to use (resp. compile) only a minimal set of drivers for your application, please add at least following "infrastructural resources":

  \li <B>src/ifx/\$(VERIF_DUT)/_Reg</B> directory
  \li <B>src/ifx/\$(VERIF_DUT)/_Lib</B> directory
  \li <B>src/ifx/SrvSw</B> directory
  \li CPU driver: <B>src/ifx/\$(VERIF_DUT)/Cpu</B> and <B>src/ifx/\$(VERIF_DUT)/_Impl/IfxCpu_cfg.*</B>
  \li DMA driver: <B>src/ifx/\$(VERIF_DUT)/Dma</B> and <B>src/ifx/\$(VERIF_DUT)/_Impl/IfxDma_cfg.*</B>
  \li Port driver: <B>src/ifx/\$(VERIF_DUT)/Port</B>, <B>src/ifx/\$(VERIF_DUT)/_Impl/IfxPort_cfg.*</B> and <B>src/ifx/\$(VERIF_DUT)/_PinMap/IfxPort_PinMap.*</B>
  \li SCU driver: <B>src/ifx/\$(VERIF_DUT)/Scu</B> and <B>src/ifx/\$(VERIF_DUT)/_Impl/IfxScu_cfg.*</B>
  \li Src driver: <B>src/ifx/\$(VERIF_DUT)/Src</B> and <B>src/ifx/\$(VERIF_DUT)/_Impl/IfxSrc_cfg.*</B>
  \li Stm driver: <B>src/ifx/\$(VERIF_DUT)/Stm</B> and <B>src/ifx/\$(VERIF_DUT)/_Impl/IfxStm_cfg.*</B>

Whenever additional drivers should be added, you typically have to copy following files/directories:

  \li <B>src/ifx/\$(VERIF_DUT)/<driver></B>
  \li <B>src/ifx/\$(VERIF_DUT)/_Impl/<driver>_cfg.*</B>
  \li <B>src/ifx/\$(VERIF_DUT)/_PinMap/<driver>_cfg.*</B>


\section agentixSetup Special Notes to the AGENtiX Setup

  \li include paths are already defined in $VERIF_SRC/include/$VERIF_DUT/build/build_defaults.inc and don't need to be defined again in testcase specific project.cfg file
  \li the default IfxCfg.h file is located under $VERIF_SRC/lld/include and doesn't need to be added to the testcase
  \li whenever a driver package should be included into a testcase, add 'MK_LLD \$(VERIF_LLD)/src/ifx/\$(VERIF_DUT)/_Build/<driver>.xml' to the BUILD section of the project.cfg file. There is no need (and it isn't recommended) to specify individual source files of a driver, since names or required files might change over time.
  \li for Aurix HE and LE derivatives, please add 'DEFINE USE_ILLD_LIBRARY 1' to the header of your project.cfg file to select the iLLD library. This isn't required for the Aurix Plus anymore, since iLLDs are an integral part of the development platform.
  \li example testcases and templates are located under $VERIF_SRC/lld/testcases/<module>

[\ref lld_doxygenRules "Previous page"] [\ref lld_versioning "Next page"]


*/
